==> qlandkartegt-0.16.1.tar.gz: qlandkartegt-0.16.1/src/CGpx.h <==
/**********************************************************************************************
    Copyright (C) 2006, 2007 Oliver Eichler oliver.eichler@gmx.de

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

**********************************************************************************************/
#ifndef CGPX_H
#define CGPX_H

#include <QObject>
#include <QMap>
#include <QColor>
#include <QString>
#include <QtXml/QDomDocument>

#include "Dictionary.h"

/// handle geo data from GPX files
class CGpx : public QObject, public QDomDocument
{
    Q_OBJECT;

    public:
        // Those are standard GPX/XML namespaces
        static const QString gpx_ns;
        static const QString xsi_ns;

        // Those are the URIs of the GPX extensions we support
        static const QString gpxx_ns;
        static const QString gpxtpx_ns;
        static const QString rmc_ns;
        static const QString ql_ns;

        enum gpx_version {
            qlVer_foreign,      // file was not created by QLandkarteGT
            qlVer_1_0,          // file uses old, non XSD-compatible extensions
            qlVer_1_1,          // file uses new, XSD-compatible extensions
        };

    public:
        CGpx(QObject * parent);
        virtual ~CGpx();

        void load(const QString& filename);
        void save(const QString& filename);

        static QMap<QString,QDomElement> mapChildElements(const QDomNode& parent);

        const Dictionary<QString, QColor>& getColorMap() const;
        const Dictionary<QString, int>& getTrackColorMap() const;

        QDomElement &getExtensions() { return extensions; };
        gpx_version version() { return file_version; }

    protected:
        void writeMetadata();

        Dictionary<QString, QColor> colorMap;
        Dictionary<QString, int> trackColorMap;

    private:
        QDomElement extensions;
        gpx_version file_version;
};
#endif                           //CGPX_H

==> qlandkartegt-1.1.0.tar.gz: qlandkartegt-1.1.0/src/CGpx.h <==
/**********************************************************************************************
    Copyright (C) 2006, 2007 Oliver Eichler oliver.eichler@gmx.de

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

**********************************************************************************************/
#ifndef CGPX_H
#define CGPX_H

#include <QObject>
#include <QMap>
#include <QColor>
#include <QString>
#include <QtXml/QDomDocument>

#include "Dictionary.h"

/// handle geo data from GPX files
class CGpx : public QObject, public QDomDocument
{
    Q_OBJECT;

    public:
        // Those are standard GPX/XML namespaces
        static const QString gpx_ns;
        static const QString xsi_ns;

        // Those are the URIs of the GPX extensions we support
        static const QString gpxx_ns;
        static const QString gpxtpx_ns;
        static const QString gpxwpx_ns;
        static const QString rmc_ns;
        static const QString ql_ns;
        static const QString gs_ns;

        enum gpx_version
        {
            qlVer_foreign,       // file was not created by QLandkarteGT
            qlVer_1_0,           // file uses old, non XSD-compatible extensions
            qlVer_1_1,           // file uses new, XSD-compatible extensions
        };

    public:
        CGpx(QObject * parent, bool = false);
        virtual ~CGpx();

        void load(const QString& filename);
        void save(const QString& filename);
        void makeExtensions();

        static QMap<QString,QDomElement> mapChildElements(const QDomNode& parent);

        const Dictionary<QString, QColor>& getColorMap() const;
        const Dictionary<QString, int>& getTrackColorMap() const;

        QDomElement &getExtensions() { return extensions; };
        gpx_version version() { return file_version; }
        bool getExportFlag() { return export_flag; }

    protected:
        void writeMetadata();

        Dictionary<QString, QColor> colorMap;
        Dictionary<QString, int> trackColorMap;

    private:
        QDomElement extensions;
        gpx_version file_version;
        bool export_flag;
};
#endif                           //CGPX_H
